==> knowledge-center-api-0.4.0-remould-20181007.092323-11-sources.jar: cn/yoofans/knowledge/center/api/dto/page/ItemDetailPageDto.java <==
package cn.yoofans.knowledge.center.api.dto.page;

import java.io.Serializable;
import java.util.List;

/**
 * 产品详情页dto
 * @author zhanghuifeng
 * @date 2018/7/5下午2:21
 */
public class ItemDetailPageDto implements Serializable {

    private static final long serialVersionUID = -2107553991639711480L;

    public static final int IS_HIDE =  1;
    public static final int NO_HIDE =  0;

    /**
     * 主键ID
     */
    private Long id;

    /**
     * 产品ID
     */
    private Long itemId;

    /**
     * 产品类型 @see ItemTypeEnum
     */
    private Integer itemType;

    /**
     * 详情名称
     */
    private String detailName;

    /**
     * 详情内容
     */
    private String content;

    /**
     * 是否默认，1：是，2：否
     * @see cn.yoofans.knowledge.center.api.enums.page.DetailPageIsDefaultEnum
     */
    private Integer isDefault;

    /**
     * 详情页与计划关联集合
     */
    private List<DetailPageItemRelationDto> relationList;

    /**
     * 文案类型，0：图文详情，1：图片详情
     * @see cn.yoofans.knowledge.center.api.enums.page.DetailPageContentTypeEnum
     */
    private Integer contentType;

    /**
     * 头图
     * @return
     */
    private String headImg;

    /**
     * 图片详情字段
     * @return
     */
    private String imgConent;

    /**
     * 是否隐藏
     */
    private Integer isHide;

    private List<String> replayImages;//复购图片地址集合

    public List<String> getReplayImages() {
        return replayImages;
    }

    public void setReplayImages(List<String> replayImages) {
        this.replayImages = replayImages;
    }

    public List<DetailPageItemRelationDto> getRelationList() {
        return relationList;
    }

    public void setRelationList(List<DetailPageItemRelationDto> relationList) {
        this.relationList = relationList;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Integer getItemType() {
        return itemType;
    }

    public void setItemType(Integer itemType) {
        this.itemType = itemType;
    }

    public Integer getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(Integer isDefault) {
        this.isDefault = isDefault;
    }

    public Integer getContentType() {
        return contentType;
    }

    public void setContentType(Integer contentType) {
        this.contentType = contentType;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }

    public String getImgConent() {
        return imgConent;
    }

    public void setImgConent(String imgConent) {
        this.imgConent = imgConent;
    }

    public Integer getIsHide() {
        return isHide;
    }

    public void setIsHide(Integer isHide) {
        this.isHide = isHide;
    }
}

==> knowledge-center-api-0.4.5-remould-20181017.060323-1-sources.jar: cn/yoofans/knowledge/center/api/dto/page/ItemDetailPageDto.java <==
package cn.yoofans.knowledge.center.api.dto.page;

import java.io.Serializable;
import java.util.List;

/**
 * 产品详情页dto
 * @author zhanghuifeng
 * @date 2018/7/5下午2:21
 */
public class ItemDetailPageDto implements Serializable {

    private static final long serialVersionUID = -2107553991639711480L;

    public static final int IS_HIDE =  1;
    public static final int NO_HIDE =  0;

    /**
     * 主键ID
     */
    private Long id;

    /**
     * 产品ID
     */
    private Long itemId;

    /**
     * 产品类型 @see ItemTypeEnum
     */
    private Integer itemType;

    /**
     * 详情名称
     */
    private String detailName;

    /**
     * 详情内容
     */
    private String content;

    /**
     * 是否默认，1：是，2：否
     * @see cn.yoofans.knowledge.center.api.enums.page.DetailPageIsDefaultEnum
     */
    private Integer isDefault;

    /**
     * 详情页与计划关联集合
     */
    private List<DetailPageItemRelationDto> relationList;

    /**
     * 文案类型，0：图文详情，1：图片详情
     * @see cn.yoofans.knowledge.center.api.enums.page.DetailPageContentTypeEnum
     */
    private Integer contentType;

    /**
     * 头图
     * @return
     */
    private String headImg;

    /**
     * 图片详情字段
     * @return
     */
    private String imgConent;

    /**
     * 是否隐藏
     */
    private Integer isHide;

    private String replayHeadImg;//头图-复购

    private String replayImages;//复购图片地址集合

    public String getReplayHeadImg() {
        return replayHeadImg;
    }

    public void setReplayHeadImg(String replayHeadImg) {
        this.replayHeadImg = replayHeadImg;
    }

    public String getReplayImages() {
        return replayImages;
    }

    public void setReplayImages(String replayImages) {
        this.replayImages = replayImages;
    }

    public List<DetailPageItemRelationDto> getRelationList() {
        return relationList;
    }

    public void setRelationList(List<DetailPageItemRelationDto> relationList) {
        this.relationList = relationList;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Integer getItemType() {
        return itemType;
    }

    public void setItemType(Integer itemType) {
        this.itemType = itemType;
    }

    public Integer getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(Integer isDefault) {
        this.isDefault = isDefault;
    }

    public Integer getContentType() {
        return contentType;
    }

    public void setContentType(Integer contentType) {
        this.contentType = contentType;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }

    public String getImgConent() {
        return imgConent;
    }

    public void setImgConent(String imgConent) {
        this.imgConent = imgConent;
    }

    public Integer getIsHide() {
        return isHide;
    }

    public void setIsHide(Integer isHide) {
        this.isHide = isHide;
    }
}
